======================
 Flask-Sitemap v0.2.0
======================

Flask-Sitemap v0.2.0 was released on January 5, 2016.

About
-----

Flask-Sitemap is a Flask extension helping with sitemap generation.

New features
------------

- Adds new command line interface to generate sitemap. (#13)

Improved features
-----------------

- Adds 'application/octet-stream' content type to GZipped response.
  (#20)

Bug fixes
---------

- Uses pytest-runner as distutils command with dependency resolution.

Notes
-----

- Improves integration of PyTest and addresses problem with missing
  test requirements.  (#15)
- If you want to use command line interface install dependencies using
  `pip install flask-sitemap[cli]`.

Installation
------------

   $ pip install Flask-Sitemap==0.2.0

Documentation
-------------

   http://flask-sitemap.readthedocs.org/en/v0.2.0

Homepage
--------

   https://github.com/inveniosoftware/flask-sitemap

Good luck and thanks for choosing Flask-Sitemap.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: http://github.com/inveniosoftware
|   URL: http://invenio-software.org
